Scratch is great for kids you can great simple code like:

```scratch:split:random
when flag clicked
say [Hi]

when flag clicked
say [Hi]
move (foo) steps
turn ccw (9) degrees

when flag clicked
clear
forever
pen down
if <<mouse down?> and <touching [mouse-pointer v]?>> then
switch costume to [button v]
else
add (x position) to [list v]
end
move (foo) steps
turn ccw (9) degrees
```
